"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.unitLabel = exports.convertToSI = exports.convert = exports.getConverter = exports.unitToKind = exports.kindToUnit = exports.unitLabelMap = void 0;

var _jsQuantities = _interopRequireDefault(require("js-quantities"));

var R = _interopRequireWildcard(require("ramda"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var unitLabelMap = {
  m2: 'm&sup2;',
  ft2: 'ft&sup2;',
  tempC: '&deg;C',
  tempF: '&deg;F',
  tempK: 'K'
};
/**
 * Returns the SI unit for a given kind.
 * @func
 * @static
 * @param {String} kind The kind to evaluate.
 * @param {object|undefined} unitSettings Settings for units.
 * @returns {String|undefined} Unit string or undefined.
 */

exports.unitLabelMap = unitLabelMap;

var kindToUnit = function kindToUnit(kind, unitSettings) {
  if (!unitSettings) {
    try {
      return (0, _jsQuantities["default"])(1, _jsQuantities["default"].getUnits(kind)[0]).toBase().units();
    } catch (_unused) {
      return undefined;
    }
  }

  var unit = unitSettings[kind];
  return unit;
};
/**
 * Get the kind from a given unit.
 * @func
 * @static
 * @param {String} unit Unit to evaluate.
 * @returns {String|undefined} Name of kind or undefined if failed.
 */


exports.kindToUnit = kindToUnit;

var unitToKind = function unitToKind(unit) {
  try {
    return (0, _jsQuantities["default"])(1, unit).kind();
  } catch (_unused2) {
    return undefined;
  }
};
/**
 * Convert given value(s) from one unit to another.
 * @func
 * @static
 * @param {String} fromUnit Unit to convert from.
 * @param {String|object} toUnit Unit to convert into OR settings for units.
 * @returns {object} A converter for given units
 */


exports.unitToKind = unitToKind;

var getConverter = function getConverter(fromUnit, toUnit) {
  try {
    if (typeof toUnit === 'string') return [toUnit, _jsQuantities["default"].swiftConverter(fromUnit, toUnit)];
    var actualToUnit = kindToUnit(unitToKind(fromUnit), toUnit);
    if (actualToUnit === undefined) return [undefined, undefined];
    return [actualToUnit, _jsQuantities["default"].swiftConverter(fromUnit, actualToUnit)];
  } catch (_unused3) {
    return [undefined, undefined];
  }
};

exports.getConverter = getConverter;
var convert = R.curry(function (fromUnit, toUnit, value) {
  return (0, _jsQuantities["default"])(value, fromUnit).to(toUnit).scalar;
});
exports.convert = convert;

var convertToSI = function convertToSI(fromUnit, value) {
  return (0, _jsQuantities["default"])(value, fromUnit).toBase().scalar;
};

exports.convertToSI = convertToSI;

var unitLabel = function unitLabel(unit) {
  var label = unitLabelMap[unit];
  return label || unit;
};

exports.unitLabel = unitLabel;